@@ -36,7 +36,7 @@ class VerifyToken:
                 db=self.mongo_db_name, collection=self.mongo_role)
         else:
             self.role_db = None
-        self.mongo_user = os.environ.get('MOGONDB_USER', None)  # 用户集合名称
+        self.mongo_user = os.environ.get('MONGODB_USER', None)  # 用户集合名称
         # 连接用户集合数据
         if self.mongo_user and self.mongo_db_name:
             self.user_db = DBConnect(
